==> nudge_leaderboard_ui-0.0.1.tar.gz: lib/features/leaderboard/presentation/widgets/rank_container.dart <==
import 'package:flutter/material.dart';

class RankContainer extends StatelessWidget {
  final int points;
  final String name;
  final int rank;

  const RankContainer({
    super.key,
    required this.points,
    required this.name,
    required this.rank,
  });
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(
        vertical: 4.0,
        horizontal: 12,
      ),
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.circular(10),
          border: Border.all(
            color: const Color.fromRGBO(230, 233, 237, 1),
            width: 2.0,
          ),
        ),
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Padding(
                padding: const EdgeInsets.only(
                  left: 16.0,
                ),
                child: RoundContainerWithNumber(
                  rank: rank,
                ),
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.4,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    AvatarContainer(
                      name: name,
                    ),
                  ],
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(
                  right: 16.0,
                ),
                child: Text(
                  '$points',
                  style: const TextStyle(
                    color: Color.fromRGBO(126, 140, 160, 1),
                    fontSize: 16,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class RoundContainerWithNumber extends StatelessWidget {
  final int rank;

  const RoundContainerWithNumber({
    super.key,
    required this.rank,
  });
  @override
  Widget build(BuildContext context) {
    return Container(
      width: 43.0, // You can adjust the width and height as needed.
      height: 43.0,
      decoration: BoxDecoration(
        color: Colors.white,
        border: Border.all(
          color: const Color.fromRGBO(208, 213, 221, 1),
          width: 2.0, // You can adjust the border width as needed.
        ),
        shape: BoxShape.circle,
      ),
      child: Center(
        child: Text(
          '$rank',
          style: const TextStyle(
            fontSize: 14.0, // You can adjust the font size as needed.
          ),
        ),
      ),
    );
  }
}

class AvatarContainer extends StatelessWidget {
  final String name;

  const AvatarContainer({
    Key? key, // Fix the super.key parameter
    required this.name,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: MediaQuery.of(context).size.width * 0.5,
      child: Row(
        children: [
          const CircularAvatarContainer(),
          const SizedBox(
            width: 10,
          ),
          Expanded(
            child: Text(
              name,
              style: const TextStyle(
                color: Colors.black,
                fontSize: 16,
                fontWeight: FontWeight.w600,
              ),
              overflow: TextOverflow.ellipsis,
            ),
          ),
        ],
      ),
    );
  }
}

class CircularAvatarContainer extends StatelessWidget {
  const CircularAvatarContainer({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 50.0,
      height: 50.0,
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        border: Border.all(
          color: Colors.blue,
          width: 2.0,
        ),
      ),
      child: const CircleAvatar(
        backgroundColor: Colors.grey,
        radius: 24.0,
        backgroundImage: AssetImage(
          'lib/core/assets/circularavatar.png',
        ),
      ),
    );
  }
}

==> nudge_leaderboard_ui-0.0.3.tar.gz: lib/features/leaderboard/presentation/widgets/rank_container.dart <==
import 'package:flutter/material.dart';

class RankContainer extends StatelessWidget {
  final int points;
  final String name;
  final int rank;

  const RankContainer({
    super.key,
    required this.points,
    required this.name,
    required this.rank,
  });
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(
        vertical: 4.0,
        horizontal: 12,
      ),
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.circular(10),
          border: Border.all(
            color: const Color.fromRGBO(230, 233, 237, 1),
            width: 2.0,
          ),
        ),
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Padding(
                padding: const EdgeInsets.only(
                  left: 16.0,
                ),
                child: RoundContainerWithNumber(
                  rank: rank,
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.4,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    AvatarContainer(
                      name: name,
                    ),
                  ],
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(
                  right: 16.0,
                ),
                child: Text(
                  '$points',
                  style: const TextStyle(
                    color: Color.fromRGBO(126, 140, 160, 1),
                    fontSize: 16,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class RoundContainerWithNumber extends StatelessWidget {
  final int rank;

  const RoundContainerWithNumber({
    super.key,
    required this.rank,
  });
  @override
  Widget build(BuildContext context) {
    return Container(
      width: 43.0, // You can adjust the width and height as needed.
      height: 43.0,
      decoration: BoxDecoration(
        color: Colors.white,
        border: Border.all(
          color: const Color.fromRGBO(208, 213, 221, 1),
          width: 2.0, // You can adjust the border width as needed.
        ),
        shape: BoxShape.circle,
      ),
      child: Center(
        child: Text(
          '$rank',
          style: const TextStyle(
            fontSize: 14.0, // You can adjust the font size as needed.
          ),
        ),
      ),
    );
  }
}

class AvatarContainer extends StatelessWidget {
  final String name;

  const AvatarContainer({
    Key? key, // Fix the super.key parameter
    required this.name,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.5,
      child: Row(
        children: [
          CircularAvatarContainer(),
          const SizedBox(
            width: 10,
          ),
          Expanded(
            child: Text(
              name,
              style: const TextStyle(
                color: Colors.black,
                fontSize: 16,
                fontWeight: FontWeight.w600,
              ),
              overflow: TextOverflow.ellipsis,
            ),
          ),
        ],
      ),
    );
  }
}

class CircularAvatarContainer extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      width: 50.0,
      height: 50.0,
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        border: Border.all(
          color: Colors.blue,
          width: 2.0,
        ),
      ),
      child: const CircleAvatar(
        backgroundColor: Colors.grey,
        radius: 24.0,
        backgroundImage: AssetImage('lib/core/assets/circularavatar.png',
            package: 'nudge_leaderboard_ui'),
      ),
    );
  }
}
